==> haskell-quickcheck-instances-0.3.18-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-instances
version: 0.3.18
id: quickcheck-instances-0.3.18-6qDoCu5nYVoGB5bCpX22vd
key: quickcheck-instances-0.3.18-6qDoCu5nYVoGB5bCpX22vd
license: BSD-3-Clause
copyright: Copyright Antoine Latter, 2012-2014
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Antoine Latter <aslatter@gmail.com>
homepage: https://github.com/phadej/qc-instances
synopsis: Common quickcheck instances
description:
    QuickCheck instances.
    .
    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.
    .
    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.
    .
    For information on writing a test-suite with Cabal
    see <https://www.haskell.org/cabal/users-guide/developing-packages.html#test-suites>
category: Testing
abi: 950281e251d952abf3e24262f3dcdb1a
exposed: True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup
    Test.QuickCheck.Instances.Tagged Test.QuickCheck.Instances.Text
    Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector
import-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-instances-0.3.18
library-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-instances-0.3.18
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/quickcheck-instances-0.3.18
hs-libraries: HSquickcheck-instances-0.3.18-6qDoCu5nYVoGB5bCpX22vd
depends:
    base-4.11.1.0 QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    array-0.5.2.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-HNWXUV6vCRnCav4TlSGszj
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=fc280138c1e1b70cf939493d29d4c902
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=bc059b0124ba79adaeef6204d1984335
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=a9e5116cfd8f4e8564ae54d9515a25b1
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             unordered-containers-0.2.9.0-HNWXUV6vCRnCav4TlSGszj=c333847eb697e0b9a0c6f4333fc78402
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=b4d53b96ebd09e78eeddd19077455aea
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-instances-0.3.19-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-instances
version: 0.3.19
id: quickcheck-instances-0.3.19-AZAv1hME1XQFmrXzPXFynr
key: quickcheck-instances-0.3.19-AZAv1hME1XQFmrXzPXFynr
license: BSD-3-Clause
copyright: Copyright Antoine Latter, 2012-2014
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Antoine Latter <aslatter@gmail.com>
homepage: https://github.com/phadej/qc-instances
synopsis: Common quickcheck instances
description:
    QuickCheck instances.
    .
    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.
    .
    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.
    .
    For information on writing a test-suite with Cabal
    see <https://www.haskell.org/cabal/users-guide/developing-packages.html#test-suites>
category: Testing
abi: 3cee6bea7ed1dad25d6e9b8e750de623
exposed: True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup
    Test.QuickCheck.Instances.Tagged Test.QuickCheck.Instances.Text
    Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector
import-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-instances-0.3.19
library-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-instances-0.3.19
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/quickcheck-instances-0.3.19
hs-libraries: HSquickcheck-instances-0.3.19-AZAv1hME1XQFmrXzPXFynr
depends:
    base-4.11.1.0 QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    array-0.5.2.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=fc280138c1e1b70cf939493d29d4c902
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=bc059b0124ba79adaeef6204d1984335
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=a9e5116cfd8f4e8564ae54d9515a25b1
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE=d999168fa5a35d048ce4f3e0442b4ae6
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=b4d53b96ebd09e78eeddd19077455aea
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
